<?php


namespace FiloBlu\Pos\Observer\Payment;

use Magento\Framework\Stdlib\CookieManagerInterface;

class MethodIsActive implements \Magento\Framework\Event\ObserverInterface
{

    const FILTER_ENABLE_CONFIG_PATH = 'filoblu_pos/general/active';
    const PAYMENT_METHODS_TO_FILTER = ['adyen_pos_cloud'];
    const POS_VISIBILITY_COOKIE_NAME = 'filoblu_pos_mode';

    /**
     * @var \Magento\Framework\App\Config\ScopeConfigInterface
     */
    protected $scopeConfig;

    protected $customerSession;

    /**
     * @var CookieManagerInterface
     */
    protected $cookieManager;

    public function __construct(
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Magento\Customer\Model\Session $customerSession,
        CookieManagerInterface $cookieManager
    )
    {
        $this->scopeConfig = $scopeConfig;
        $this->customerSession = $customerSession;
        $this->cookieManager = $cookieManager;
    }

    /**
     * Filter out payment methods if customer is not logged in by admin and if pos mode is not active
     *
     * @param \Magento\Framework\Event\Observer $observer
     * @return void
     */
    public function execute(
        \Magento\Framework\Event\Observer $observer
    ) {
        $methodIsActive = $observer->getEvent()->getResult();
        $methodInstance =  $observer->getEvent()->getMethodInstance();
        $quote = $observer->getEvent()->getQuote();

        if (!$this->scopeConfig->isSetFlag(self::FILTER_ENABLE_CONFIG_PATH, \Magento\Store\Model\ScopeInterface::SCOPE_WEBSITE)) {
            return;
        }

        if ($this->customerSession->getLoggedAsCustomerAdmindId() != NULL) {
            return;
        }

        $isPosModeEnabled = $this->cookieManager->getCookie(self::POS_VISIBILITY_COOKIE_NAME, 0);
        if ($isPosModeEnabled == 1) {
            return;
        }
        
        if (in_array($methodInstance->getCode(), self::PAYMENT_METHODS_TO_FILTER)) {
            $methodIsActive->setData('is_available', FALSE);
        }



    }
}
